@@ -25,9 +25,6 @@ import warnings
 
 import dill
 import numpy as np
-from sympy2c import __version__ as sympy2c_version
-from sympy2c.compiler import base_cache_folder, load_module
-
 from PyCosmo import core_file_handling
 from PyCosmo.Background import Background, _call
 from PyCosmo.BoltzmannSolver.LinearPerturbationBoltzmann import (
@@ -35,6 +32,10 @@ from PyCosmo.BoltzmannSolver.LinearPerturbationBoltzmann import (
 )
 from PyCosmo.LinearPerturbationApprox import LinearPerturbationApprox
 
+from sympy2c import __version__ as sympy2c_version
+from sympy2c.compiler import base_cache_folder, load_module
+from sympy2c.utils import get_platform
+
 from ._Util import get_active_branch_name
 from .config import INFO, check_flattened, load_parameters_ini
 from .ini_handling import Bunch
@@ -106,8 +107,10 @@ class Cosmo(object):
 
         branch = get_active_branch_name() or ""
 
+        platform = get_platform()
+
         folder = os.path.join(
-            base_cache_folder(), "PyCosmo", branch, version.replace(".", "_")
+            base_cache_folder(), "PyCosmo", platform, branch, version.replace(".", "_")
         )
         if not os.path.exists(folder):
             try:
@@ -328,7 +331,7 @@ class Cosmo(object):
         else:
             raise ValueError("invalid value '{}' for recombination".format(recomb))
 
-        self.background = background = Background(params, self.rec, self._wrapper)
+        self.background = background = Background(self, params, self.rec, self._wrapper)
 
         if params.pk_type == "boltz":
             a_table = 10 ** np.linspace(-15, 0, params.table_size)
@@ -349,7 +352,7 @@ class Cosmo(object):
                 params.pk_nonlin_type = None
                 warnings.warn(
                     "disabled non-linear perturbations which are not working "
-                    "with the Boltzmann solver yet", 
+                    "with the Boltzmann solver yet",
                 )
         else:
             # Todo raise an error
@@ -433,12 +436,12 @@ class Cosmo(object):
         # critical density at z=0 [h^2 M_sun Mpc^-3]
         derived_parameters.rho_crit = (
             3.0
-            * derived_parameters.H0 ** 2
+            * derived_parameters.H0**2
             / (8.0 * np.pi * params.G)
             * 1e6
             * params.mpc
             / params.msun
-            / params.h ** 2
+            / params.h**2
         )
         # TODO: check omega_gamma and omega_neu expressions
         # omega_photon (see Dodelson eq. 2.70) ** express in terms of H0? **)
@@ -449,14 +452,14 @@ class Cosmo(object):
         if params.N_massive_nu != 0:
             derived_parameters.N_eff = (
                 params.N_massless_nu
-                + self.model_specific_parameters.T_mnu ** 4
+                + self.model_specific_parameters.T_mnu**4
                 * (4 / 11) ** -(4 / 3)
                 * params.N_massive_nu
             )
 
         derived_parameters.rho_gamma_eV = (
-            (3 * 100 ** 2 / (8 * np.pi * params.G))
-            * params.hbar ** 3
+            (3 * 100**2 / (8 * np.pi * params.G))
+            * params.hbar**3
             * (1 / (params.mpc * 1e-3)) ** 2
             * (1 / (params.evc2))
             * (params.c * 1e3) ** 3
@@ -465,7 +468,7 @@ class Cosmo(object):
         derived_parameters.T_0 = params.Tcmb * ((4 / 11) ** (1 / 3))
         derived_parameters.rho_mnu_eV = (
             3.0
-            * derived_parameters.H0 ** 2
+            * derived_parameters.H0**2
             * (params.hbar) ** 3
             * (params.c * 1e3) ** 3
             / (8 * np.pi * params.G)
@@ -475,7 +478,7 @@ class Cosmo(object):
         )
 
         derived_parameters.omega_gamma_prefactor = (
-            np.pi ** 2
+            np.pi**2
             / 15
             * (2.725 * params.kb) ** 4
             / (derived_parameters.rho_gamma_eV)
@@ -483,7 +486,7 @@ class Cosmo(object):
         derived_parameters.omega_gamma = (
             derived_parameters.omega_gamma_prefactor
             * (params.Tcmb / 2.725) ** 4
-            / params.h ** 2
+            / params.h**2
             * nudge[1]
         )
         derived_parameters.omega_neu = (
@@ -573,13 +576,13 @@ class Cosmo(object):
 
         # derived_parameters.H_0 = 100 * params.h
 
-        omh2 = params.omega_m * params.h ** 2
+        omh2 = params.omega_m * params.h**2
 
         derived_parameters._sigma_27 = params.Tcmb / 2.7  # Normalised CMB temperature
 
         # Wave vector values
         derived_parameters._k_eq = (
-            7.46e-2 * omh2 * derived_parameters._sigma_27 ** -2
+            7.46e-2 * omh2 * derived_parameters._sigma_27**-2
         )  # Eq. (3), units: Mpc^-1
 
         # Redshift values
@@ -587,15 +590,15 @@ class Cosmo(object):
         # it to avoid confusion
         # Redshift at matter-radiation equality, Eq. (2)
         derived_parameters._z_equality = (
-            2.5e4 * omh2 * derived_parameters._sigma_27 ** -4
+            2.5e4 * omh2 * derived_parameters._sigma_27**-4
         )
-        b_1 = 0.313 * omh2 ** -0.419 * (1.0 + 0.607 * omh2 ** 0.674)
-        b_2 = 0.238 * omh2 ** 0.223
+        b_1 = 0.313 * omh2**-0.419 * (1.0 + 0.607 * omh2**0.674)
+        b_2 = 0.238 * omh2**0.223
         derived_parameters._z_drag = (
             1291.0
-            * (omh2 ** 0.251)
-            / (1.0 + 0.659 * omh2 ** 0.828)
-            * (1.0 + b_1 * (params.omega_b * params.h ** 2) ** b_2)
+            * (omh2**0.251)
+            / (1.0 + 0.659 * omh2**0.828)
+            * (1.0 + b_1 * (params.omega_b * params.h**2) ** b_2)
         )  # Redshift at drag epoch, Eq. (4)
 
         # Comoving distance values
@@ -645,9 +648,9 @@ class Cosmo(object):
         R = (
             31.5
             * params.omega_b
-            * params.h ** 2
+            * params.h**2
             * derived_parameters._sigma_27 ** (-4)
-            * (z / 10 ** 3) ** (-1.0)
+            * (z / 10**3) ** (-1.0)
         )
 
         return R
