@@ -158,18 +158,15 @@ def check_ini(params):
 assert l_max > 2, "l_max must be at least 3"
 
 # compute the energy density of dark energy
-omega_l_a = (
-    IfThenElse(
-        flat_universe,
-        (1 - omega_m - omega_r),
-        omega_l,
-    )
-    * a ** (-3 * (1 + w0))
-)
+omega_l_a = IfThenElse(
+    flat_universe,
+    (1 - omega_m - omega_r),
+    omega_l,
+) * a ** (-3 * (1 + w0))
 omega_k = 1 - omega_m - omega_r - omega_l_a.subs({a: 1})
 
 # Friedmann equation
-H = H0 * (omega_r * a ** -4 + omega_m * a ** -3 + omega_k * a ** -2 + omega_l_a) ** (
+H = H0 * (omega_r * a**-4 + omega_m * a**-3 + omega_k * a**-2 + omega_l_a) ** (
     1 / 2
 )
 
@@ -178,7 +175,7 @@ R = 3 / 4 * omega_b / omega_gamma * a
 # symbolic integration of the integrand does not work in all cases, so we use numerical
 # approximation here:
 Ht = H.subs({a: t})  # H as function of t
-integrand = 1.0 / Ht / t ** 2
+integrand = 1.0 / Ht / t**2
 chi = Integral(integrand, t, a, 1)
 print("chi", integrand)
 
@@ -192,7 +189,7 @@ def initial_cosmics():
     Initial conditions as defined in Cosmics
     """
     eta_0 = Min(1e-3 / k, 1e-1 * h)
-    adotrad = 2.8948e-7 * Tcmb ** 2
+    adotrad = 2.8948e-7 * Tcmb**2
 
     a_0 = eta_0 / h * adotrad
 
@@ -232,7 +229,7 @@ def initial_cosmics():
             + 2.0
             / 3.0
             * (k / (a_0 * H0_scaled)) ** 2
-            / (omega_m / a_0 ** 3 + 4.0 / 3.0 * omega_r / a_0 ** 4)
+            / (omega_m / a_0**3 + 4.0 / 3.0 * omega_r / a_0**4)
             * phi
         )
     )
@@ -331,7 +328,7 @@ def initial_class():
     # the initial time is same as in Cosmics,
     # we do not set it iteratively as in CLASS
     eta_0_approx = Min(1e-3 / k, 1e-1 * h)
-    adotrad = 2.8948e-7 * Tcmb ** 2
+    adotrad = 2.8948e-7 * Tcmb**2
 
     a_0 = eta_0_approx / h * adotrad
 
@@ -344,7 +341,7 @@ def initial_class():
     # da/d(eta)/a [h Mpc^-1]
     a_prime_over_a = a_0 * ha
     # om=H0*Omega_m/sqrt(Omega_r) [h Mpc^-1]
-    om = omega_m / omega_r ** 0.5 / rh
+    om = omega_m / omega_r**0.5 / rh
     # neutrino/radiation (constant) ratio [1]
     fracnu = omega_neu / omega_r
     # dark matter/matter (constant) ratio[1]
@@ -356,8 +353,8 @@ def initial_class():
     # matter to radiation energy density (time-dependent)ratio [1]
     rho_m_over_rho_r = omega_m / omega_r * a_0
     ktau = k * eta_0
-    ktau_two = ktau ** 2
-    ktau_three = ktau ** 3
+    ktau_two = ktau**2
+    ktau_three = ktau**3
 
     # initial perturbations in synchronous gauge and in Ma&Bertschinger95 notation
     delta_g = -ktau_two / 3.0 * (1.0 - om * eta_0 / 5.0)  # photon density
@@ -407,7 +404,7 @@ def initial_class():
     eta_sync = 1.0 - ktau_two / 12.0 / (15.0 + 4.0 * fracnu) * (
         5.0
         + 4.0 * fracnu
-        - (16.0 * fracnu ** 2 + 280.0 * fracnu + 325.0)
+        - (16.0 * fracnu**2 + 280.0 * fracnu + 325.0)
         / 10.0
         / (2.0 * fracnu + 15.0)
         * eta_0
@@ -509,15 +506,15 @@ courant_1 = a * H_Mpc * eta_interp(a)
 econ = (
     (-2 / 3 * (k / (a * H0_Mpc)) ** 2 * Phi)
     + (
-        (omega_dm * delta + omega_b * delta_b) / a ** 3
-        + 4 * (omega_gamma * Theta[0] + omega_neu * N[0]) / a ** 4
+        (omega_dm * delta + omega_b * delta_b) / a**3
+        + 4 * (omega_gamma * Theta[0] + omega_neu * N[0]) / a**4
     )
     + (3 * a * H_Mpc / k)
     * (
-        (omega_dm * u + omega_b * u_b) / a ** 3
-        + 4 * (omega_gamma * Theta[1] + omega_neu * N[1]) / a ** 4
+        (omega_dm * u + omega_b * u_b) / a**3
+        + 4 * (omega_gamma * Theta[1] + omega_neu * N[1]) / a**4
     )
-) / ((omega_dm + omega_b) / a ** 3 + (omega_gamma + omega_neu) / a ** 4)
+) / ((omega_dm + omega_b) / a**3 + (omega_gamma + omega_neu) / a**4)
 
 
 def rhs(H=H_Mpc, H0=H0_Mpc, R=R):
@@ -538,13 +535,13 @@ def rhs(H=H_Mpc, H0=H0_Mpc, R=R):
     Pi = Theta[2] + Theta_P[0] + Theta_P[2]
     dPhi_dlan = (
         Psi
-        - k_H ** 2 * Phi / 3.0
+        - k_H**2 * Phi / 3.0
         + (H0 / H) ** 2
         / 2
         * (
-            (omega_dm * delta + omega_b * delta_b) * a ** -3
+            (omega_dm * delta + omega_b * delta_b) * a**-3
             + omega_l_a * delta_de
-            + 4 * (omega_gamma * Theta[0] + omega_neu * N[0]) * a ** -4
+            + 4 * (omega_gamma * Theta[0] + omega_neu * N[0]) * a**-4
         )
     )
 
