@@ -65,9 +65,9 @@ def fft_top_hat(x):  # pragma: no cover
             continue
 
         elif y > 1e-2:
-            t[i] = 3.0 * (np.sin(y) - y * np.cos(y)) / y ** 3.0
+            t[i] = 3.0 * (np.sin(y) - y * np.cos(y)) / y**3.0
         else:
-            t[i] = 1.0 - y ** 2.0 / 10.0 + y ** 4.0 / 280.0
+            t[i] = 1.0 - y**2.0 / 10.0 + y**4.0 / 280.0
 
     return t
 
@@ -114,7 +114,7 @@ def integral_halo(k, m_msun, nu_range, rv_mpc, c, a, f, eta):
 
     nufuncs = m_msun[:, None, :].T * nu_range[:, None, None] * f[:, None, None]
     u_km = _u_km_slow(k, a, c, rv_mpc, nu_range, eta)
-    integrand_1halo = nufuncs * u_km ** 2.0
+    integrand_1halo = nufuncs * u_km**2.0
     integral_1halo = np.trapz(integrand_1halo, np.log(nu_range), axis=0)
     return integral_1halo
 
@@ -127,9 +127,10 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
     and `Mead et al. 2016 <https://arxiv.org/abs/1602.02154>`_ .
 
     .. Warning ::
-        NonLinearPerturbationMead not supported by the Boltzmann solver yet.
-        Calling any function from this module while using the Boltzmann solver (pk_type = 'boltz') will return
-        **AttributeError: 'NoneType' object has no attribute 'function'**
+        NonLinearPerturbationMead not supported by the Boltzmann solver yet.  Calling
+        any function from this module while using the Boltzmann solver (pk_type =
+        'boltz') will return **AttributeError: 'NoneType' object has no attribute
+        'function'**
     """
 
     def __init__(self, cosmo):
@@ -166,7 +167,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
             self._params.mf_n = -0.243
 
         self._params.rho_crit_Msun_iMpc3 = (
-            3 * self._params.H0 ** 2 / (8 * np.pi * self._params.G_mead)
+            3 * self._params.H0**2 / (8 * np.pi * self._params.G_mead)
         )
         self._params.rho_matter_Msun_iMpc3 = (
             self._params.rho_crit_Msun_iMpc3 * self._params.omega_m
@@ -249,7 +250,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
 
     def _alpha(self, a):
         n = self.neff(a)
-        alpha = 3.24 * 1.85 ** n
+        alpha = 3.24 * 1.85**n
         alpha[alpha > 2] = 2
         alpha[alpha < 0.5] = 0.5
         return alpha
@@ -287,7 +288,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         nk, na = pk.shape
         assert k.shape == (nk,)
 
-        D = k[:, None] ** 3 * pk / (2 * np.pi ** 2)
+        D = k[:, None] ** 3 * pk / (2 * np.pi**2)
 
         return D
 
@@ -317,7 +318,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         :return: Mass of sphere in solar masses [Msun].
         """
 
-        mass = 4.0 / 3.0 * np.pi * r_mpc ** 3.0 * self._params.rho_matter_Msun_iMpc3
+        mass = 4.0 / 3.0 * np.pi * r_mpc**3.0 * self._params.rho_matter_Msun_iMpc3
 
         return mass
 
@@ -370,8 +371,8 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         x = np.atleast_1d(x)
         return np.where(
             x > 1e-2,
-            3.0 / x ** 4 * (x ** 2 * np.sin(x) - 3.0 * np.sin(x) + 3.0 * x * np.cos(x)),
-            -x / 5.0 + x ** 3 / 70.0,
+            3.0 / x**4 * (x**2 * np.sin(x) - 3.0 * np.sin(x) + 3.0 * x * np.cos(x)),
+            -x / 5.0 + x**3 / 70.0,
         )
 
     def neff(self, a):
@@ -481,7 +482,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         pk = self._lin_pert.powerspec_a_k(a=a, k=k)
         res = np.trapz(k[:, None] ** 3 * pk * w[:, None] ** 2, lnk, axis=0)
 
-        sig8z = np.sqrt(1.0 / (2.0 * np.pi ** 2) * res)
+        sig8z = np.sqrt(1.0 / (2.0 * np.pi**2) * res)
         return sig8z
 
     def _calc_sigma_integral(self, k, m_msun, a):
@@ -511,7 +512,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
 
         t = self.T(x=r_mpc * k[:, None, None])
         assert t.shape == (nk, nm, na)
-        integrand_mpc = ps * t ** 2.0 * k[:, None, None] ** 3.0
+        integrand_mpc = ps * t**2.0 * k[:, None, None] ** 3.0
 
         integral = np.trapz(integrand_mpc, np.log(k), axis=0)
 
@@ -567,11 +568,12 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         r"""
         Multiplicity function :math:`f(\nu)` as it appears in the calculation of the
         Halo Mass Function.  The available fitting functions are
-        `Press & Schechter, 1974 <https://ui.adsabs.harvard.edu/abs/1974ApJ...187..425P/abstract>`_,
+        `Press & Schechter,
+        1974 <https://ui.adsabs.harvard.edu/abs/1974ApJ...187..425P/abstract>`_,
         `Sheth & Tormen, 1999 <https://arxiv.org/abs/astro-ph/9901122>`_ ,
         and `Tinker et al., 2010 <https://arxiv.org/abs/1001.3162>`_ .
 
-        :param nu: array of :math:`\nu` values as in :math:`\nu = \delta_c / \sigma(M)` \
+        :param nu: array of :math:`\nu` values as in :math:`\nu = \delta_c / \sigma(M)`\
             (see eq. 17 in `Mead et al., 2015 <https://arxiv.org/abs/1505.07833>`_)
         :return: Multiplicity function :math:`f(\nu)` .
 
@@ -588,7 +590,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         if self._params.multiplicity_fnct == "PS":
             # Press & Schechter, 'Formation of Galaxies and Clusters of Galaxies by
             # self-similar gravitational condensation' (1974)
-            f = np.sqrt(2.0 / np.pi) * np.exp(-(nu ** 2.0) / 2.0)
+            f = np.sqrt(2.0 / np.pi) * np.exp(-(nu**2.0) / 2.0)
 
         elif self._params.multiplicity_fnct == "ST":
             # Sheth & Tormen, 'Large-scale bias and the peak background split', 1999
@@ -597,8 +599,8 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
             #   - self._params.mf_a * nu ** 2. / 2.)
 
             f = 0.2161599864561661 * (
-                (1.0 + (self._params.mf_a * nu ** 2.0) ** (-self._params.mf_p))
-                * np.exp(-self._params.mf_a * nu ** 2.0 / 2.0)
+                (1.0 + (self._params.mf_a * nu**2.0) ** (-self._params.mf_p))
+                * np.exp(-self._params.mf_a * nu**2.0 / 2.0)
             )
 
         elif self._params.multiplicity_fnct == "Ti":
@@ -607,7 +609,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
                 self._params.mf_aa
                 * (1.0 + (self._params.mf_b * nu) ** (-2.0 * self._params.mf_a))
                 * nu ** (2.0 * self._params.mf_n)
-                * np.exp(-self._params.mf_c * nu ** 2.0 / 2)
+                * np.exp(-self._params.mf_c * nu**2.0 / 2)
             )
         else:
             raise NotImplementedError(
@@ -778,11 +780,12 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
 
     def powerspec_a_k(self, a=1.0, k=0.1, diag_only=False):
         r"""
-        Calculates the non-linear matter power spectrum, using the ``mead`` model, as described in \
+        Calculates the non-linear matter power spectrum, using the ``mead`` model, as
+        described in \
         `Mead et al., 2015 <https://arxiv.org/abs/1505.07833>`_ and \
         `Mead et al., 2016 <https://arxiv.org/abs/1602.02154>`_,
         consisting of the superposition
-        of the :meth:`pk_1h` and :meth:`pk_2h` terms. 
+        of the :meth:`pk_1h` and :meth:`pk_2h` terms.
 
 
         :param k: wavelength :math:`[Mpc]^{-1}`
@@ -827,7 +830,7 @@ class NonLinearPerturbationMead(NonLinearPerturbationBase):
         # Adapt the transition between 1-halo and 2-halo term as described in Eq. (27)
         # of Mead et al, 2015
         alpha = self._alpha(a)
-        pk = (pk_1h ** alpha + pk_2h ** alpha) ** (1.0 / alpha)
+        pk = (pk_1h**alpha + pk_2h**alpha) ** (1.0 / alpha)
         pk[:, mask_invalid] = np.nan
         if diag_only:
             return np.diag(pk)
